@@ -107,7 +107,6 @@ class Smart(Generic[_T]):
         dictionary, key = get_nested_dictionary_and_key(
             dictionary=self._params,
             name=name,
-            set_mode=False,
         )
 
         if init:
@@ -131,7 +130,6 @@ class Smart(Generic[_T]):
         dictionary, key = get_nested_dictionary_and_key(
             dictionary=self._params,
             name=name,
-            set_mode=False,
         )
         value = dictionary.pop(key)
         if init:
@@ -142,7 +140,6 @@ class Smart(Generic[_T]):
         dictionary, key = get_nested_dictionary_and_key(
             dictionary=self._params,
             name=name,
-            set_mode=False,
         )
         dictionary[key] = value = function(dictionary[key])
         return value
@@ -150,16 +147,33 @@ class Smart(Generic[_T]):
     def update(
         self,
         source: Union['Smart', Dict[str, Any], List[str], Path],
+        name: Optional[str] = None,
         override: bool = True,
     ) -> 'Smart':
         if isinstance(source, Smart):
-            self._update_from_smart(source, override)
+            self._update_from_smart(
+                smart=source,
+                name=name,
+                override=override,
+            )
         elif isinstance(source, dict):
-            self._update_from_dict(source, override)
+            self._update_from_dict(
+                params=source,
+                name=name,
+                override=override,
+            )
         elif isinstance(source, list):
-            self._update_from_list(source, override)
+            self._update_from_list(
+                params_list=source,
+                name=name,
+                override=override,
+            )
         elif isinstance(source, Path):
-            self._update_from_path(source, override)
+            self._update_from_path(
+                path=source,
+                name=name,
+                override=override,
+            )
         else:
             raise TypeError(f"Source type '{type(source)}' is not supported.")
 
@@ -268,25 +282,66 @@ class Smart(Generic[_T]):
 
         return self
 
-    def _update_from_smart(self, smart: 'Smart', override: bool) -> None:
-        _flatten_keys = self.flatten_keys()
-        for key in smart.flatten_keys():
-            if override or not check_key_override(key, _flatten_keys):
-                self.set(key, smart.get(key))
+    def _update_from_smart(
+        self,
+        smart: 'Smart',
+        name: Optional[str],
+        override: bool,
+    ) -> None:
+        if name is None:
+            _flatten_keys = self.flatten_keys()
+            for key in smart.flatten_keys():
+                if override or not check_key_override(key, _flatten_keys):
+                    self.set(key, smart.get(key))
+        else:
+            try:
+                self.update(
+                    source=smart.get(name),
+                    override=override,
+                )
+            except Exception as e:
+                raise RuntimeError(f"Cannot update with source name '{name}'. " + ' '.join(e.args))
 
-    def _update_from_dict(self, params: Dict[str, Any], override: bool) -> None:
-        self._update_from_smart(Smart(**params), override)
+    def _update_from_dict(
+        self,
+        params: Dict[str, Any],
+        name: Optional[str],
+        override: bool,
+    ) -> None:
+        self._update_from_smart(
+            smart=Smart(**params),
+            name=name,
+            override=override,
+        )
 
-    def _update_from_list(self, params_list: List[str], override: bool) -> None:
+    def _update_from_list(
+        self,
+        params_list: List[str],
+        name: Optional[str],
+        override: bool,
+    ) -> None:
         smart: Smart = Smart()
         for param in params_list:
             key, value = parse_param(param)
             smart.set(key, value)
 
-        self._update_from_smart(smart, override)
+        self._update_from_smart(
+            smart=smart,
+            name=name,
+            override=override,
+        )
 
-    def _update_from_path(self, path: Path, override: bool) -> None:
-        self._update_from_dict(load_data(path), override)
+    def _update_from_path(
+        self,
+        path: Path,
+        name: Optional[str],
+        override: bool,
+    ) -> None:
+        self._update_from_dict(
+            params=load_data(path),
+            name=name,
+            override=override,
+        )
 
     def _instantiate(self, obj: Any, location: str) -> Any:
         if isinstance(obj, dict):
